@@ -176,6 +176,17 @@ class Exceldefinition:
                         f"Column do not support Raise Ranking feature. Column: {column_name}"
                     )
 
+        if len(invalid_definitions) == 0:
+            self.store.sort(key=lambda c: c[0], reverse=False)
+
+            if len(self.store) > 0 and (
+                self.store[0][0] != 1
+                or self.store[len(self.store) - 1][0] != len(self.store)
+            ):
+                invalid_definitions.append(
+                    f"Column Index must be in continuation and starts from 1."
+                )
+
         return invalid_definitions
 
     @staticmethod
@@ -210,8 +221,8 @@ class Exceldefinition:
         return result
 
     @property
-    def column_count(self):
-        return len(self.store)
+    def max_column_index(self) -> int:
+        return self.store[len(self.store) - 1][0]
 
     def get_sort_strategy_priorities(self) -> "list":
         return self.sort_strategy_priority
